@@ -1,6 +1,6 @@
 package Dancer2::Plugin::DBIC;
 
-our $VERSION = '0.0011'; # VERSION
+our $VERSION = '0.0012'; # VERSION
 
 use strict;
 use warnings;
@@ -10,7 +10,16 @@ use DBICx::Sugar;
 
 sub _schema {
     my ($dsl, $name) = @_;
-    DBICx::Sugar::config( plugin_setting );
+    my $config;
+    # ugly switch needed to support plugin2 plugins which use this plugin
+    # whilst still working for plugin1
+    if ( $dsl->app->can('with_plugin') ) {
+        $config = $dsl->config;
+    }
+    else {
+        $config = plugin_setting;
+    }
+    DBICx::Sugar::config( $config );
     return DBICx::Sugar::schema($name);
 };
 
@@ -41,7 +50,7 @@ Dancer2::Plugin::DBIC - DBIx::Class interface for Dancer2 applications
 
 =head1 VERSION
 
-version 0.0011
+version 0.0012
 
 =head1 SYNOPSIS
 
